from bs4 import BeautifulSoup
import requests
from abc import ABC, abstractmethod
from urllib.parse import urljoin
from .config import config

class BaseScraper():
    def __init__(self):
        self.base_url = config.get_base_url()

    @abstractmethod
    def scrape(self, endpoint: str, params: dict) -> str:
        pass

    def get_soup(self, endpoint: str, params: dict) -> BeautifulSoup:
        full_url = urljoin(self.base_url, endpoint)
        response = requests.get(full_url, params=params)
        print(response.url)
        return BeautifulSoup(response.text, 'html.parser')



from .base import VideoDetailsScraper

class DetailsScraper(VideoDetailsScraper):
    def details(self, video_url: str) -> str:
        return self.scrape(video_url)
    def download_high_quality(self, video_url: str, filename: str):
        video_details = self.scrape(video_url)
        high_url = video_details.get('files', {}).get('high')
        if high_url:
            return self.download_high(high_url, filename)

    def download_low_quality(self, video_url: str, filename: str):
        video_details = self.scrape(video_url)
        low_url = video_details.get('files', {}).get('low')
        if low_url:
            return self.download_low(low_url, filename)